netapp_ontap.models.system_firmware API documentation
Description: Copyright &copy; 2026 NetApp Inc. All rights reserved …

# Module `netapp_ontap.models.system_firmware`

Copyright © 2026 NetApp Inc. All rights reserved.

This file has been automatically generated based on the ONTAP REST API documentation.

## Classes

`class SystemFirmwareSchema (*, only: types.StrSequenceOrSet | None = None, exclude: types.StrSequenceOrSet = (), many: bool | None = None, context: dict | None = None, load_only: types.StrSequenceOrSet = (), dump_only: types.StrSequenceOrSet = (), partial: bool | types.StrSequenceOrSet | None = None, unknown: str | None = None)`

  The fields of the SystemFirmware object

  ### Ancestors

  - netapp_ontap.resource.ResourceSchema
  - marshmallow.schema.Schema
  - marshmallow.base.SchemaABC
  - abc.ABC

  ### Class variables

  `boot_media_bios_version: str GET`

    BIOS version that is currently staged on the boot media of the node.

    Example: 13.16

  `boot_media_loader_version: str GET`

    LOADER version that is currently staged on the boot media of the node.

    Example: 8.2.0

  `install_pending: bool GET`

    Flag that indicates if the system firmware install is pending. A true value suggests that a node reboot or cluster upgrade is required for completing installation.

    Example: false

  `running_bios_version: str GET`

    BIOS version that is currently installed on the node.

    Example: 13.16

  `running_loader_version: str GET`

    LOADER version that is currently installed on the node.

    Example: 8.2.0